
/*
  Analog in/PWM out on 4 channels

 Reads 4 analog input pins, and maps the result to a range (from 0 to 255) to a corresponding output pin.

The circuit:
* Individual analog signals input to analog pin 0,1,2,&3.
   Individual PWM signals are output through PWM pins 5,6,9,&10.
   Input/Output values are printed to the Serial Monitor. 
 created 29 Dec. 2008
modified 9 Apr 2012
by Tom Igoe
modified further 20 March 2013
by Aaron Kovacs
added averaging/smoothing code 5/12/2013
by Jason Rohr
*/

// These constants won't change.  They're used to give names
// to the pins used:
const int analogInPin1 = A0;  // Analog input pin that is attached to the signal after the voltage divider.
const int analogOutPin1 = 10;  // Digital output pin tied to the above input pin. 
const int analogInPin2 = A1;  // Analog input pin that is attached to the signal after the voltage divider.
const int analogOutPin2 = 9;  // Digital output pin tied to the above input pin.
const int analogInPin3 = A2;  // Analog input pin that is attached to the signal after the voltage divider.
const int analogOutPin3 = 6;  // Digital output pin tied to the above input pin.
const int analogInPin4 = A3;  // Analog input pin that is attached to the signal after the voltage divider.
const int analogOutPin4 = 5; // Digital output pin tied to the above input pin.

int sensorValue1 = 0;        // value read from the specified pin.
int AveragedOfMappedValue1 = 0;  // averaged value now output to the PWM (analog out)
int mappedValue1 = 0;        // averaged analog sensor value

int sensorValue2 = 0;        // value read from the specified pin.
int AveragedOfMappedValue2 = 0;  // averaged value now output to the PWM (analog out)
int mappedValue2 = 0;        // value output to the PWM (analog out)

int sensorValue3 = 0;        // value read from the specified pin.
int AveragedOfMappedValue3 = 0;  // averaged value now output to the PWM (analog out)
int mappedValue3 = 0;        // value output to the PWM (analog out)

int sensorValue4 = 0;        // value read from the specified pin.
int AveragedOfMappedValue4 = 0;  // averaged value now output to the PWM (analog out)
int mappedValue4 = 0;        // value output to the PWM (analog out)

                              // SMOOTHing / averaging part of code:

const int numReadings = 60;     //  how many previous values do we want to average?
int readings1[numReadings];      // the readings from the analog input
int readings2[numReadings];
int readings3[numReadings];
int readings4[numReadings];

int index1 = 0;                  // the index of the current reading
int index2 = 0;
int index3 = 0;
int index4 = 0;

int total1 = 0;                  // the running total
int total2 = 0;
int total3 = 0;
int total4 = 0;


int average1 = 0;                // the average
int average2 = 0;
int average3 = 0;
int average4 = 0;


void setup()  {

   // initialize serial communications at 9600 bps:

   Serial.begin(9600);
//for (int thisReading = 0; thisReading < numReadings; thisReading++)
//    readings[thisReading] = 0; 

}



void loop() {

                                                              
  //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

sensorValue1 = analogRead(analogInPin1);                      // read the analog in value:
                                                              // subtract the last reading:
  mappedValue1 = map(sensorValue1, 0, 1023, 0, 255);          // map it to the range of the analog out 
  total1= total1 - readings1[index1];                          // read from the sensor:
  readings1[index1] = mappedValue1;                            // add the reading to the total:                             
  total1= total1 + readings1[index1];                          // advance to the next position in the array:                        
  index1 = index1 + 1;                    
                                                               // if we're at the end of the array...
  if (index1 >= numReadings)                                   // ...wrap around to the beginning:
    index1 = 0;                          

                                                    // calculate the average:
  AveragedOfMappedValue1 = total1 / numReadings;    // this is the AVERAGE that we want to write for our final pwm value to write to LED driver pin
  if (AveragedOfMappedValue1 < 0)
      AveragedOfMappedValue1 = 0;
      
  analogWrite(analogOutPin1, AveragedOfMappedValue1);         //write it to LED driver pin
  Serial.print("Analog In Pin A0 = " );                      
  Serial.print(sensorValue1);     
  Serial.print("\t Digital Out 10= ");     
  Serial.println(AveragedOfMappedValue1);  
  
  
                
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

sensorValue2 = analogRead(analogInPin2);            
                                                              // subtract the last reading:
  mappedValue2 = map(sensorValue2, 0, 1023, 0, 255);          // map it to the range of the analog out 
  total2= total2 - readings2[index2];                          // read from the sensor:
  readings2[index2] = mappedValue2;                            // add the reading to the total:                             
  total2= total2 + readings2[index2];                          // advance to the next position in the array:                        
  index2 = index2 + 1;                    
                                                               // if we're at the end of the array...
  if (index2 >= numReadings)                                   // ...wrap around to the beginning:
    index2 = 0;                          

                                                    // calculate the average:
  AveragedOfMappedValue2 = total2 / numReadings;    // this is the AVERAGE that we want to write for our final pwm value to write to LED driver pin
  if (AveragedOfMappedValue2 < 0)
      AveragedOfMappedValue2 = 0;
  
  analogWrite(analogOutPin2, AveragedOfMappedValue2);         //write it to LED driver pin
  Serial.print("Analog In Pin A01 = " );                      
  Serial.print(sensorValue2);     
  Serial.print("\t Digital Out 9= ");     
  Serial.println(AveragedOfMappedValue2);  
  
  
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

sensorValue3 = analogRead(analogInPin3);            
                                                              // subtract the last reading:
  mappedValue3 = map(sensorValue3, 0, 1023, 0, 255);          // map it to the range of the analog out 
  total3= total3 - readings3[index3];                          // read from the sensor:
  readings3[index3] = mappedValue3;                            // add the reading to the total:                             
  total3= total3 + readings3[index3];                          // advance to the next position in the array:                        
  index3 = index3 + 1;                    
                                                               // if we're at the end of the array...
  if (index3 >= numReadings)                                   // ...wrap around to the beginning:
    index3 = 0;                          

                                                    // calculate the average:
  AveragedOfMappedValue3 = total3 / numReadings;    // this is the AVERAGE that we want to write for our final pwm value to write to LED driver pin
  if (AveragedOfMappedValue3 < 0)
      AveragedOfMappedValue3 = 0;
  
  analogWrite(analogOutPin3, AveragedOfMappedValue3);         //write it to LED driver pin
  Serial.print("Analog In Pin A02 = " );                      
  Serial.print(sensorValue3);     
  Serial.print("\t Digital Out 6= ");     
  Serial.println(AveragedOfMappedValue3);  
  
  
  //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

sensorValue4 = analogRead(analogInPin4);            
                                                              // subtract the last reading:
  mappedValue4 = map(sensorValue4, 0, 1023, 0, 255);          // map it to the range of the analog out 
  total4= total4 - readings4[index4];                          // read from the sensor:
  readings4[index4] = mappedValue4;                            // add the reading to the total:                             
  total4= total4 + readings4[index4];                          // advance to the next position in the array:                        
  index4 = index4 + 1;                    
                                                               // if we're at the end of the array...
  if (index4 >= numReadings)                                   // ...wrap around to the beginning:
    index4 = 0;                          

                                                    // calculate the average:
  AveragedOfMappedValue4 = total4 / numReadings;    // this is the AVERAGE that we want to write for our final pwm value to write to LED driver pin
  if (AveragedOfMappedValue1 < 0)
      AveragedOfMappedValue1 = 0;
  
  analogWrite(analogOutPin4, AveragedOfMappedValue4);         //write it to LED driver pin
  Serial.print("Analog In Pin A03 = " );                      
  Serial.print(sensorValue4);     
  Serial.print("\t Digital Out 5= ");     
  Serial.println(AveragedOfMappedValue4);  
  
  
  delay(1000);   // wait 1000 milliseconds before the next loop   Set how often you want the loop to run here:
                 // for the analog-to-digital converter to settle
                // after the last reading:


                           
}


